@@ -68,15 +68,9 @@
 #include "MButton.h"
 #include "Vlist.h"
 
-#ifdef VMS
-#   include <unixlib.h>
-#   include "strcasecmp.h"
-#   include <stat.h>
-#else
-#   include <string.h>
-#   include <sys/stat.h>
-#   include <unistd.h>
-#endif
+#include <string.h>
+#include <sys/stat.h>
+#include <unistd.h>
 
 #include "types.h"
 #include "actions.h"
@@ -177,6 +171,7 @@ enum
 
 static struct option const GNU_longOptions[] =
   {
+    {"grayscale", no_argument, NULL, GRAYSCALE_ARG},
     {"center", no_argument, NULL, CENTER_ARG},
     {"nocenter", no_argument, NULL, NOCENTER_ARG},
     {"scale", required_argument, NULL, SCALE_ARG},
@@ -321,11 +316,12 @@ int main(argc, argv)
     Dimension    maximum_width,maximum_height;
     unsigned int gwidth=0,gheight=0;
     int          dim_forced;
+    int          opt_counter=0;
+    int          c;
 
 /*###  initializing global variables ####################################*/
 
     INFMESSAGE(initializing global variables)
-    pdf_delaysafer_hack = 0;
     gv_scroll_mode = SCROLL_MODE_NONE;
     gv_class = GV_CLASS;
     gv_pending_page_request=NO_CURRENT_PAGE;
@@ -342,11 +338,7 @@ int main(argc, argv)
     versionpopup     = NULL;
     FileSel_popup    = NULL;
     pagemediaEntry   = NULL;
-#ifdef VMS
-    gv_print_kills_file = 1;
-#else
     gv_print_kills_file = 0;
-#endif
 
     antialias_p = 0;
     noantialias_p = 0;
@@ -394,7 +386,6 @@ int main(argc, argv)
 
    INFMESSAGE(opening display)
    {
-#ifndef VMS
      /*
        The following doesn't work for XFILESEARCHPATH since stupid
        XtResolvePathname, when passed a NULL path, checks XFILESEARCHPATH
@@ -404,11 +395,9 @@ int main(argc, argv)
      char *xuf;
      xuf = getenv(xufsp); if (xuf) xuf = GV_XtNewString(xuf);
      setenv(xufsp,"___",1);
-#endif
      gv_display = XtOpenDisplay(app_con,NULL,NULL,gv_class,NULL,0,&argc,argv);
-#ifndef VMS
+
      if (xuf) { setenv(xufsp,xuf,1); GV_XtFree(xuf); } else unsetenv(xufsp);
-#endif
      if (!gv_display) {
        fprintf(stderr, "%s: Unable to open the display.\n", GV_APPLICATION_NAME);
        exit(EXIT_STATUS_ERROR);
@@ -419,9 +408,7 @@ int main(argc, argv)
    }
 
    /*### Manage GNU command line arguments ########################*/
-   int opt_counter = 0;
-   int c;
-   while ((c = getopt_long (argc, argv, "vhu", GNU_longOptions, NULL))
+   while ((c = getopt_long_only (argc, argv, "vhu", GNU_longOptions, NULL))
 	  != -1)
      {
 
@@ -607,7 +594,7 @@ int main(argc, argv)
      XrmDatabase db;
      INFMESSAGE(getting resources)
      db = resource_buildDatabase(gv_display,gv_class,gv_name,&argc,argv);
-     XrmCombineDatabase(db,&gv_database,True);
+     XrmCombineDatabase(db,&gv_database,False);
    }
 
 /*### initializing widget set and creating application shell #########################*/
