@@ -79,17 +79,11 @@
 
 #define GV_MAXLENGTH 512
 
-#ifdef VMS
-#   include<descrip.h>
-#   include<lnmdef.h>
-#   include<lib$routines.h>
-#   include<starlet.h>
-#   include<rmsdef.h>
-#else  
+
 #   include <sys/types.h>
 #   include <sys/stat.h>
 #   include <unistd.h>
-#endif
+
 
 #include <math.h>
 
@@ -113,10 +107,6 @@
 #include "Ghostview.h"
 #include "Vlist.h"
 
-#ifdef VMS
-#   include <unixio.h>
-#   define unlink remove
-#endif
 
 #include "types.h"
 #include "actions.h"
@@ -302,9 +292,11 @@ misc_resetPagePosition()
 /*############################################################*/
 
 void
-misc_setPageMarker(entry,kind)
+misc_setPageMarker(entry,kind,event,check_toc)
   int entry;
   int kind; /* 0 = selected, 1 = highlighted , 2 = bring selected in sight*/
+  XEvent *event;
+  Boolean check_toc;
 {
   int x,y,yl,yu,ny=99999;
   Boolean b = False;
@@ -331,9 +323,12 @@ misc_setPageMarker(entry,kind)
 	ny = (int)newtocClip->core.height - ((int)newtoc->core.y + yl + 14);
         if (y>ny) b = True;
       }
-      if (b) {
+      if (event && b) {
 	INFIMESSAGE(jumping to,ny)
 	ClipWidgetSetCoordinates(newtocClip,x,ny);
+	entry = VlistEntryOfPosition(newtoc,(int)event->xbutton.y+(y-ny));
+	if (entry != VlistHighlighted(newtoc) && check_toc)
+		VlistChangeHighlighted(newtoc,entry,XawVlistSet);
       }
     }
   }
@@ -403,6 +398,7 @@ String misc_changeFile(name)
   String error=NULL;
   char *p;
   Boolean b = False;
+  char *dir, *q;
 
   BEGINMESSAGE(misc_changeFile)
 
@@ -413,6 +409,14 @@ String misc_changeFile(name)
     if (!b && file_fileIsNotUseful(p)) sprintf(p,"%s.ps",name);  else b = True;
     if (!b && file_fileIsNotUseful(p)) sprintf(p,"%s.pdf",name); else b = True;
     if (!b)                            strcpy(p,name);
+    dir=file_getDirOfPath(p);
+    if(strcmp(dir,p)) {
+      chdir(dir);
+      /* Strip off directory from p to satisfy GS 8.00 security change */
+      q=p;
+      while(*dir && *dir == *q) {dir++; q++;}
+      strcpy(p,q);
+    }
   }
   name = p;
   INFSMESSAGE(trying to open,name)
@@ -491,9 +495,6 @@ int mode;
    struct stat sbuf;
    char *tmpname;
    int  r = -1;
-#  ifdef VMS
-      char *pos;
-#  endif
 
    BEGINMESSAGE(check_file)
 
@@ -508,11 +509,9 @@ int mode;
       return(0);
    }
 
-#ifdef VMS
-   if (mode&CHECK_FILE_DATE) {
-#else
+
    if (1) {
-#endif
+
       INFMESSAGE(checking file date)
       status = stat(gv_filename, &sbuf);
       if (!status && mtime != sbuf.st_mtime) {
@@ -525,58 +524,7 @@ int mode;
    tmpname=gv_filename;
    r=status;
 
-#ifdef VMS
 
-   if ( (mode&CHECK_FILE_VERSION) ||
-        (status && (mode&CHECK_FILE_DATE) && strrchr(gv_filename,';'))
-      ) {
-      tmpname = GV_XtNewString(gv_filename);
-      pos = strrchr(tmpname,';'); /* strip the version */
-      if (pos) *pos='\0';
-      status = stat(tmpname, &sbuf);
-      if (!status) {
-         if (mtime != sbuf.st_mtime) {
-            if (pos) { /* get the full specification of the new file*/
-               unsigned long s;
-               char newfile[256];
-               struct dsc$descriptor_s sd;
-               struct dsc$descriptor_s fd;
-               unsigned long context = 0;       
-
-               sd.dsc$w_length  = (unsigned short)strlen(tmpname);
-               sd.dsc$b_dtype   = DSC$K_DTYPE_T;
-               sd.dsc$b_class   = DSC$K_CLASS_S;
-               sd.dsc$a_pointer = tmpname;
-               fd.dsc$w_length  = sizeof(newfile)-1;
-               fd.dsc$b_dtype   = DSC$K_DTYPE_T;
-               fd.dsc$b_class   = DSC$K_CLASS_S;
-               fd.dsc$a_pointer = newfile;
-               s=lib$find_file(&sd,&fd,&context,0,0,0,0);
-               if (s != RMS$_SUC) {
-                  INFMESSAGE(not found) r = -1;
-               } else {
-                  newfile[fd.dsc$w_length]='\0';
-                  pos = strchr(newfile,' ');
-                  if (pos) *pos = '\0';
-                  INFSMESSAGE(found new file:,newfile)
-                  if (gv_filename_old) GV_XtFree(gv_filename_old);
-                  gv_filename_old = gv_filename;
-                  gv_filename=GV_XtNewString(newfile);
-                  INFSMESSAGE(new file:,gv_filename)
-                  r = 1;
-               }
-               lib$find_file_end(&context);
-             } else { /* file changed, but filename shows no version number */
-                INFSMESSAGE(new file:,gv_filename)
-                r = 1;
-             }
-         } else {
-           INFMESSAGE(no new version)
-           r = 0;
-         }
-      } else r=status;
-   }
-#endif /* VMS */
 
    if (r<0) {
      char message[GV_MAXLENGTH]; 
@@ -690,7 +638,7 @@ render_page(gvw)
        }
        if (toc_text) {
 	 INFMESSAGE(marking current_page as current)
-         misc_setPageMarker(current_page,0);
+         misc_setPageMarker(current_page,0,NULL,True);
        }
     }
 
@@ -989,14 +937,8 @@ setup_ghostview()
           bitmap = app_res.document_bitmap;
        } 
        else if (gv_filename) {
-#        ifdef VMS
-           buttonlabel = strrchr(gv_filename,']');
-	   if (!buttonlabel) buttonlabel = strrchr(gv_filename,':');
-	   if (buttonlabel) buttonlabel++;
-	   else buttonlabel = gv_filename;
-#        else
+
 	   buttonlabel = gv_filename;
-#        endif
 	   label = gv_filename;
 	   bitmap = None;
        } else {
@@ -1036,32 +978,7 @@ setup_ghostview()
     }
 
     /* Reset ghostscript and output messages popup */
-#   ifdef VMS
-    {
-       Bool disable=False;
-       if ( !doc || !olddoc ||
-	    olddoc->beginprolog != doc->beginprolog ||
-	    olddoc->endprolog != doc->endprolog ||
-	    olddoc->beginsetup != doc->beginsetup ||
-	    olddoc->endsetup != doc->endsetup
-       ) disable=True;
-       if (!disable) {
-          char *fn = GV_XtNewString(gv_filename);
-          char *ofn= GV_XtNewString(gv_filename_old);
-          char *pos;
-          pos = strrchr(fn,';');  if (pos) *pos='\0';
-          pos = strrchr(ofn,';'); if (pos) *pos='\0';
-          if (strcmp(fn, ofn)) disable=True;
-          GV_XtFree(fn);
-          GV_XtFree(ofn);
-       }
-       if (disable==True) {   
-	  GhostviewDisableInterpreter(page);
-          cb_popdownInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
-          cb_resetInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
-       }
-    }
-#   else
+
     if (!doc || !olddoc ||
 	strcmp(gv_filename_old, gv_filename) ||
 	olddoc->beginprolog != doc->beginprolog ||
@@ -1073,7 +990,6 @@ setup_ghostview()
         cb_popdownInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
         cb_resetInfoPopup((Widget)NULL,(XtPointer)NULL,(XtPointer)NULL);
     }
-#   endif
 
     /* Build table of contents */
     if (doc && doc->structured) {
@@ -1132,7 +1048,11 @@ setup_ghostview()
 	}
 	s[i] = '\0';
 							n=0;
-	XtSetArg(args[n], XtNvlist, s);			n++;
+	if (	(!gv_filename_old)			||
+		(!olddoc)				||
+		(strcmp(gv_filename_old, gv_filename))	||
+		(doc->numpages != olddoc->numpages)	)
+		  XtSetArg(args[n], XtNvlist, s);	n++;
 	XtSetArg(args[n], XtNlabel, toc_text);		n++;
       } else {
 	s = NULL;
@@ -1155,7 +1075,7 @@ setup_ghostview()
     misc_setSensitive(w_printAllPages     , show_printAllPages     , (gv_psfile   != NULL));
     misc_setSensitive(w_checkFile         , show_checkFile         , (gv_filename != NULL));
     misc_setSensitive(w_updateFile        , show_updateFile        , (gv_filename != NULL));
-    misc_setSensitive(w_showThisPage      , show_showThisPage      , (gv_filename != NULL));
+    misc_setSensitive(w_showThisPage      , show_showThisPage      , (gv_psfile   != NULL));
     misc_setSensitive(w_prevPage          , show_prevPage          , (toc_text    != NULL));
     misc_setSensitive(w_nextPage          , show_nextPage          , (gv_filename != NULL));
     misc_setSensitive(w_toggleCurrentPage , show_toggleCurrentPage , (toc_text    != NULL));
@@ -1169,7 +1089,7 @@ setup_ghostview()
     XtSetSensitive(saveAllEntry,     (gv_psfile   != NULL));
     XtSetSensitive(saveMarkedEntry,  (toc_text    != NULL));
     XtSetSensitive(nextEntry,        (gv_filename != NULL));
-    XtSetSensitive(redisplayEntry,   (gv_filename != NULL));
+    XtSetSensitive(redisplayEntry,   (gv_psfile   != NULL));
     XtSetSensitive(prevEntry,        (toc_text    != NULL));
     XtSetSensitive(currentEntry,     (toc_text    != NULL));
     XtSetSensitive(oddEntry,         (toc_text    != NULL));
@@ -1719,3 +1639,51 @@ catch_Xerror(dpy, err)
     ENDMESSAGE(catch_Xerror)
     return 0;
 }
+
+/*############################################################*/
+/* quote_filename */
+/* Quotes special characters in filenames */
+/* (taken from bash sources) */
+/*############################################################*/
+
+char *
+quote_filename (string) 
+     char *string;
+{
+    int c;
+    char *result, *r, *s;
+
+    BEGINMESSAGE(quote_filename)
+
+    result = (char*) GV_XtMalloc((2 * strlen (string) + 1) * sizeof(char));
+
+    for (r = result, s = string; s && (c = *s); s++)
+    {
+      switch (c)
+	{
+	case ' ': case '\t': case '\n':		/* IFS white space */
+	case '\'': case '"': case '\\':		/* quoting chars */
+	case '|': case '&': case ';':		/* shell metacharacters */
+	case '(': case ')': case '<': case '>':
+	case '!': case '{': case '}':		/* reserved words */
+	case '*': case '[': case '?': case ']':	/* globbing chars */
+	case '^':
+	case '$': case '`':			/* expansion chars */
+	  *r++ = '\\';
+	  *r++ = c;
+	  break;
+	case '#':				/* comment char */
+	  if (s == string)
+	    *r++ = '\\';
+	  /* FALLTHROUGH */
+	default:
+	  *r++ = c;
+	  break;
+	}
+    }
+    *r = '\0';
+
+    ENDMESSAGE(quote_filename)
+
+    return (result);
+}
