@@ -122,11 +122,10 @@ XrmDatabase resource_buildDatabase(display,app_class,app_name,argcP,argv)
 {
   XrmDatabase db=NULL;
   String *sP;
-  String s,t;
+  String s,t, rpath;
+  char *spartan_filename;
   char tmp[GV_MAX_FILENAME_LENGTH];
-#ifdef VMS
-  int b;
-#endif
+
 
   BEGINMESSAGE(resource_buildDatabase)
 
@@ -137,34 +136,20 @@ XrmDatabase resource_buildDatabase(display,app_class,app_name,argcP,argv)
 
   /* ### system resources ################# */
   INFMESSAGE(checking for system resources)
-    /* #ifdef VMS */
-    /*   b=0; */
-    /*   sprintf(tmp,"DECW$USER_DEFAULTS:%s_SYSTEM.DAT",app_class); */
-    /*   if (!file_fileIsNotUseful(tmp)) b=1; */
-    /*   if (!b) { */
-    /*     sprintf(tmp,"DECW$SYSTEM_DEFAULTS:%s_SYSTEM.DAT",app_class); */
-    /*     if (!file_fileIsNotUseful(tmp)) b=1; */
-    /*   } */
-    /*   if (b) s = GV_XtNewString(tmp); */
-    /*   else s = NULL; */
-    /* #else */
-    //  s = XtResolvePathname(display,"app-defaults",NULL,NULL,NULL,NULL,0,NULL);
-    /* #endif */
 
-    String rpath = GV_XtNewString(GV_LIBDIR);
-    if (rpath) {
-      INFSMESSAGE(merging system resource file into database,rpath)
-	XrmCombineFileDatabase(rpath,&db,True);
-      resource_system_file = rpath;
-    }
+  rpath = GV_XtMalloc (strlen (GV_LIBDIR) + strlen ("/gv_system.ad"));
+  rpath[0] = '\0';
+  strcat (rpath, GV_LIBDIR);
+  strcat (rpath, "/gv_system.ad");
+  if (rpath) {
+    INFSMESSAGE(merging system resource file into database,rpath)
+      XrmCombineFileDatabase(rpath,&db,True);
+    resource_system_file = rpath;
+  }
 
   /* ### user resources ################# */
   INFMESSAGE(checking for user resources)
-#ifdef VMS
-    sprintf(tmp,"DECW$USER_DEFAULTS:%s.DAT",app_class);
-  if (file_fileIsNotUseful(tmp)) s=NULL;
-  else s = GV_XtNewString(tmp);
-#else
+
   strcpy(tmp,USER_DEFAULTS);
   file_translateTildeInPath(tmp);
   if (!file_fileIsNotUseful(tmp)) {
@@ -173,7 +158,6 @@ XrmDatabase resource_buildDatabase(display,app_class,app_name,argcP,argv)
     s = getenv("XUSERFILESEARCHPATH");
     if (s) s = XtResolvePathname(display,NULL,NULL,NULL,s,NULL,0,NULL);
   }
-#endif
   if (s) {
     INFSMESSAGE(merging user resource file into database,s)
       XrmCombineFileDatabase(s,&db,True);
@@ -225,7 +209,13 @@ XrmDatabase resource_buildDatabase(display,app_class,app_name,argcP,argv)
     }
   if (spartan_p)
     {
-      resource_putResource (&db, app_name, ".style", "gv_spartan.dat");
+      spartan_filename = (char *) 
+	GV_XtMalloc (strlen(GV_LIBDIR) + strlen ("/gv_spartan.dat") + 1);
+      spartan_filename[0] = '\0';
+      strcat(spartan_filename, GV_LIBDIR);
+      strcat(spartan_filename, "/gv_spartan.dat");
+      resource_putResource (&db, app_name, ".style", spartan_filename);
+      GV_XtFree (spartan_filename);
     }
   if (quiet_p)
     {
@@ -357,6 +347,12 @@ XrmDatabase resource_buildDatabase(display,app_class,app_name,argcP,argv)
       } else s = t;
     }
 #   else
+    
+    /*
+     * Do not use fallback styles
+     *
+     */
+
     INFSMESSAGE(merging style resource file into database,s)
       t = resource_mergeFileIntoDatabase(&db,s);
     if (!t) {
@@ -579,22 +575,15 @@ static char* resource_mergeFileIntoDatabase(dbP,name)
     INFSMESSAGE(not useful,tmp)
       if (name != file_locateFilename(name)) useful=-1;
       else {
-#     ifdef VMS
-        sprintf(tmp,"DECW$USER_DEFAULTS:%s",name);
-#     else
+
 	sprintf(tmp,"~/%s",name);
 	file_translateTildeInPath(tmp);
-#     endif
+
       }
   } else useful=1;
 
   if (!useful) {
-#   ifdef VMS
-    if (file_fileIsNotUseful(tmp)) {
-      INFSMESSAGE(not useful,tmp)
-	sprintf(tmp,"SYS$LOGIN:%s",name);
-    } else useful=1;     
-#   endif
+
     if (!useful && file_fileIsNotUseful(tmp)) {
       INFSMESSAGE(not useful,tmp)
 	sprintf(tmp,"%s%s",GV_LIBDIR,name);
