@@ -40,8 +40,8 @@
 #define  VERSION_APPLIC_CONTEXT	app_con  			/* the Application Context */
 
 char *versionIdentification[] = {
-        "gv 3.6.1",
-        "December 2004",
+        "gv 3.6.2",
+        "September 2006",
 	0
 };
 
@@ -56,7 +56,7 @@ char * copyright = "\
  gv -- An X11 user interface for Ghostscript. \n\
  \n\
  Copyright (C) 1992-1997  Johannes Plass, Timothy O. Theisen  \n\
- Copyright (C) 2004 Jose E. Marchesi \n\
+ Copyright (C) 2004,2005,2006 Jose E. Marchesi \n\
  \n\
  This program is free software; you can redistribute it and/or modify \n\
  it under the terms of the GNU General Public License as published by \n\
@@ -77,7 +77,9 @@ char *author[] = {
 "\
    GNU Maintainer:      Jose E. Marchesi (jemarch@gnu.org)\n\
 \n\
-   Original Author:     Johannes Plass\
+   Original Author:     Johannes Plass\n\
+\n\
+   See the `AUTHORS' file for a complete contributors list\
 ",
 "\
  Please send error reports to:  bug-gv@gnu.org \n\
